==> jc-1.4.0.tar.gz: soot/toolkits/scalar/CollectionFlowUniverse.h <==
// public class soot.toolkits.scalar.CollectionFlowUniverse

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 3d03fad3c1252472 soot_toolkits_scalar_CollectionFlowUniverse

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_toolkits_scalar_CollectionFlowUniverse_H_
#define _JC_soot_toolkits_scalar_CollectionFlowUniverse_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_util_Collection$object;
struct _jc_java_util_Iterator$object;
struct _jc_java_util_Set$object;

// Typedefs
typedef struct _jc_soot_toolkits_scalar_CollectionFlowUniverse$sub_refs	_jc_soot_toolkits_scalar_CollectionFlowUniverse$sub_refs;
typedef struct _jc_soot_toolkits_scalar_CollectionFlowUniverse$sub_nonrefs	_jc_soot_toolkits_scalar_CollectionFlowUniverse$sub_nonrefs;
typedef struct _jc_soot_toolkits_scalar_CollectionFlowUniverse$refs	_jc_soot_toolkits_scalar_CollectionFlowUniverse$refs;
typedef struct _jc_soot_toolkits_scalar_CollectionFlowUniverse$nonrefs	_jc_soot_toolkits_scalar_CollectionFlowUniverse$nonrefs;
typedef struct _jc_soot_toolkits_scalar_CollectionFlowUniverse$object	_jc_soot_toolkits_scalar_CollectionFlowUniverse$object;

typedef const struct _jc_soot_toolkits_scalar_CollectionFlowUniverse$vmethods	_jc_soot_toolkits_scalar_CollectionFlowUniverse$vmethods;
typedef const struct _jc_soot_toolkits_scalar_CollectionFlowUniverse$vtable	_jc_soot_toolkits_scalar_CollectionFlowUniverse$vtable;
typedef const struct _jc_soot_toolkits_scalar_CollectionFlowUniverse$vtype	_jc_soot_toolkits_scalar_CollectionFlowUniverse$vtype;

// Constructors
extern void _jc_soot_toolkits_scalar_CollectionFlowUniverse$method$_init$f10d3ead4f9e91ce(_jc_env *, struct _jc_soot_toolkits_scalar_CollectionFlowUniverse$object *, struct _jc_object *);

// Virtual methods
extern struct _jc_object *_jc_soot_toolkits_scalar_CollectionFlowUniverse$method$iterator$3cc91493d50f531c(_jc_env *, struct _jc_soot_toolkits_scalar_CollectionFlowUniverse$object *);
extern jint _jc_soot_toolkits_scalar_CollectionFlowUniverse$method$size$345df5220fc60ade(_jc_env *, struct _jc_soot_toolkits_scalar_CollectionFlowUniverse$object *);
extern _jc_object_array *_jc_soot_toolkits_scalar_CollectionFlowUniverse$method$toArray$408321282fd84959(_jc_env *, struct _jc_soot_toolkits_scalar_CollectionFlowUniverse$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_toolkits_scalar_CollectionFlowUniverse$method_info$iterator$3cc91493d50f531c;
extern _jc_method _jc_soot_toolkits_scalar_CollectionFlowUniverse$method_info$size$345df5220fc60ade;
extern _jc_method _jc_soot_toolkits_scalar_CollectionFlowUniverse$method_info$toArray$408321282fd84959;

// Virtual methods structure
struct _jc_soot_toolkits_scalar_CollectionFlowUniverse$vmethods {
	struct _jc_object	*(*iterator$3cc91493d50f531c)(_jc_env *, struct _jc_soot_toolkits_scalar_CollectionFlowUniverse$object *);
	jint	(*size$345df5220fc60ade)(_jc_env *, struct _jc_soot_toolkits_scalar_CollectionFlowUniverse$object *);
	_jc_object_array	*(*toArray$408321282fd84959)(_jc_env *, struct _jc_soot_toolkits_scalar_CollectionFlowUniverse$object *);
};

// Vtable
struct _jc_soot_toolkits_scalar_CollectionFlowUniverse$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_toolkits_scalar_CollectionFlowUniverse$vmethods	soot_toolkits_scalar_CollectionFlowUniverse;
};

// Vtype
struct _jc_soot_toolkits_scalar_CollectionFlowUniverse$vtype {
	_jc_type			type;
	_jc_soot_toolkits_scalar_CollectionFlowUniverse$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_toolkits_scalar_CollectionFlowUniverse$sub_refs {
	struct _jc_object	*elements;
};

// Reference instance fields (object)
struct _jc_soot_toolkits_scalar_CollectionFlowUniverse$refs {
    _jc_soot_toolkits_scalar_CollectionFlowUniverse$sub_refs	soot_toolkits_scalar_CollectionFlowUniverse;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_toolkits_scalar_CollectionFlowUniverse$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_toolkits_scalar_CollectionFlowUniverse$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_toolkits_scalar_CollectionFlowUniverse$sub_nonrefs	soot_toolkits_scalar_CollectionFlowUniverse;
};

// Object instance structure
struct _jc_soot_toolkits_scalar_CollectionFlowUniverse$object {
	_jc_soot_toolkits_scalar_CollectionFlowUniverse$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_toolkits_scalar_CollectionFlowUniverse$vtype	*vtype;
	_jc_soot_toolkits_scalar_CollectionFlowUniverse$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_toolkits_scalar_CollectionFlowUniverse$vtype _jc_soot_toolkits_scalar_CollectionFlowUniverse$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_toolkits_scalar_CollectionFlowUniverse, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_toolkits_scalar_CollectionFlowUniverse$class_object;

#endif	/* _JC_soot_toolkits_scalar_CollectionFlowUniverse_H_ */

==> jc-1.4.6.tar.gz: soot/toolkits/scalar/CollectionFlowUniverse.h <==
// public class soot.toolkits.scalar.CollectionFlowUniverse

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 3d03fad3c1252472 soot_toolkits_scalar_CollectionFlowUniverse

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_toolkits_scalar_CollectionFlowUniverse_H_
#define _JC_soot_toolkits_scalar_CollectionFlowUniverse_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_util_Collection$object;
struct _jc_java_util_Iterator$object;
struct _jc_java_util_Set$object;

// Typedefs
typedef struct _jc_soot_toolkits_scalar_CollectionFlowUniverse$sub_refs	_jc_soot_toolkits_scalar_CollectionFlowUniverse$sub_refs;
typedef struct _jc_soot_toolkits_scalar_CollectionFlowUniverse$sub_nonrefs	_jc_soot_toolkits_scalar_CollectionFlowUniverse$sub_nonrefs;
typedef struct _jc_soot_toolkits_scalar_CollectionFlowUniverse$refs	_jc_soot_toolkits_scalar_CollectionFlowUniverse$refs;
typedef struct _jc_soot_toolkits_scalar_CollectionFlowUniverse$nonrefs	_jc_soot_toolkits_scalar_CollectionFlowUniverse$nonrefs;
typedef struct _jc_soot_toolkits_scalar_CollectionFlowUniverse$object	_jc_soot_toolkits_scalar_CollectionFlowUniverse$object;

typedef const struct _jc_soot_toolkits_scalar_CollectionFlowUniverse$vmethods	_jc_soot_toolkits_scalar_CollectionFlowUniverse$vmethods;
typedef const struct _jc_soot_toolkits_scalar_CollectionFlowUniverse$vtable	_jc_soot_toolkits_scalar_CollectionFlowUniverse$vtable;
typedef const struct _jc_soot_toolkits_scalar_CollectionFlowUniverse$vtype	_jc_soot_toolkits_scalar_CollectionFlowUniverse$vtype;

// Constructors
extern void _jc_soot_toolkits_scalar_CollectionFlowUniverse$method$_init$f10d3ead4f9e91ce(_jc_env *, struct _jc_soot_toolkits_scalar_CollectionFlowUniverse$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_object *_jc_soot_toolkits_scalar_CollectionFlowUniverse$method$iterator$3cc91493d50f531c(_jc_env *, struct _jc_soot_toolkits_scalar_CollectionFlowUniverse$object *) _JC_JCNI_ATTR;
extern jint _jc_soot_toolkits_scalar_CollectionFlowUniverse$method$size$345df5220fc60ade(_jc_env *, struct _jc_soot_toolkits_scalar_CollectionFlowUniverse$object *) _JC_JCNI_ATTR;
extern _jc_object_array *_jc_soot_toolkits_scalar_CollectionFlowUniverse$method$toArray$408321282fd84959(_jc_env *, struct _jc_soot_toolkits_scalar_CollectionFlowUniverse$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_toolkits_scalar_CollectionFlowUniverse$method_info$iterator$3cc91493d50f531c;
extern _jc_method _jc_soot_toolkits_scalar_CollectionFlowUniverse$method_info$size$345df5220fc60ade;
extern _jc_method _jc_soot_toolkits_scalar_CollectionFlowUniverse$method_info$toArray$408321282fd84959;

// Virtual methods structure
struct _jc_soot_toolkits_scalar_CollectionFlowUniverse$vmethods {
	struct _jc_object	*(*iterator$3cc91493d50f531c)(_jc_env *, struct _jc_soot_toolkits_scalar_CollectionFlowUniverse$object *) _JC_JCNI_ATTR;
	jint	(*size$345df5220fc60ade)(_jc_env *, struct _jc_soot_toolkits_scalar_CollectionFlowUniverse$object *) _JC_JCNI_ATTR;
	_jc_object_array	*(*toArray$408321282fd84959)(_jc_env *, struct _jc_soot_toolkits_scalar_CollectionFlowUniverse$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_toolkits_scalar_CollectionFlowUniverse$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_toolkits_scalar_CollectionFlowUniverse$vmethods	soot_toolkits_scalar_CollectionFlowUniverse;
};

// Vtype
struct _jc_soot_toolkits_scalar_CollectionFlowUniverse$vtype {
	_jc_type			type;
	_jc_soot_toolkits_scalar_CollectionFlowUniverse$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_toolkits_scalar_CollectionFlowUniverse$sub_refs {
	struct _jc_object	*elements;
};

// Reference instance fields (object)
struct _jc_soot_toolkits_scalar_CollectionFlowUniverse$refs {
    _jc_soot_toolkits_scalar_CollectionFlowUniverse$sub_refs	soot_toolkits_scalar_CollectionFlowUniverse;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_toolkits_scalar_CollectionFlowUniverse$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_toolkits_scalar_CollectionFlowUniverse$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_toolkits_scalar_CollectionFlowUniverse$sub_nonrefs	soot_toolkits_scalar_CollectionFlowUniverse;
};

// Object instance structure
struct _jc_soot_toolkits_scalar_CollectionFlowUniverse$object {
	_jc_soot_toolkits_scalar_CollectionFlowUniverse$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_toolkits_scalar_CollectionFlowUniverse$vtype	*vtype;
	_jc_soot_toolkits_scalar_CollectionFlowUniverse$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_toolkits_scalar_CollectionFlowUniverse$vtype _jc_soot_toolkits_scalar_CollectionFlowUniverse$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_toolkits_scalar_CollectionFlowUniverse, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_toolkits_scalar_CollectionFlowUniverse$class_object;

#endif	/* _JC_soot_toolkits_scalar_CollectionFlowUniverse_H_ */
